/* 
   IM Caf - A Java Based Instant Messaging System
   Author: Bruno Freitas - 08/2004
   Contact: bootsector@ig.com.br
 
   Copyright (c) 2004 Bruno Freitas

   Permission is hereby granted, free of charge, to any person obtaining a copy of
   this software and associated documentation files (the "Software"), to deal in 
   the Software without restriction, including without limitation the rights to 
   use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies 
   of the Software, and to permit persons to whom the Software is furnished to do 
   so, subject to the following conditions:

   The above copyright notice and this permission notice shall be included in all 
   copies or substantial portions of the Software.

   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR 
   IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, 
   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE 
   AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
   LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, 
   OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE 
   SOFTWARE.
*/

import java.awt.*;
import java.awt.event.*;
import javax.swing.*;

public class AddNewContactDialog extends JDialog {
   private JLabel lblID;
   private JTextField txtID;
   private JPanel dataPanel, btnsPanel;
   private JButton btnOk, btnCancel;
   private ServerConnection serverConn;
   
   public AddNewContactDialog(Frame owner, ServerConnection serverConn) {
      super(owner, "Add a new Contact", true);
      
      lblID = new JLabel("Contact ID:");
      
      txtID = new JTextField();
      
      dataPanel = new JPanel(new GridLayout(2,1));
      
      dataPanel.add(lblID);
      dataPanel.add(txtID);
      
      btnsPanel = new JPanel(new GridLayout(1, 2));
      
      EvntListener handler = new EvntListener();
      
      btnOk = new JButton("Add");
      btnOk.setMnemonic('A');
      btnOk.setIcon(new ImageIcon(getClass().getResource("res/img/confirm.png")));
      btnOk.addActionListener(handler);
      btnCancel = new JButton("Close");
      btnCancel.setMnemonic('C');
      btnCancel.setIcon(new ImageIcon(getClass().getResource("res/img/closewindow.png")));
      btnCancel.addActionListener(handler);
      
      btnsPanel.add(btnOk);
      btnsPanel.add(btnCancel);
      
      getContentPane().add(dataPanel, BorderLayout.NORTH);
      getContentPane().add(btnsPanel, BorderLayout.SOUTH);
      
      getRootPane().setDefaultButton(btnOk);
      
      setSize(190, 100);
      setDefaultCloseOperation(JDialog.DISPOSE_ON_CLOSE);
      setLocationRelativeTo(owner);
      setResizable(false);
      
      this.serverConn = serverConn;
   }
   
   private class EvntListener implements ActionListener {
      
      public void actionPerformed(ActionEvent e) {
         String passwd, cpasswd, info, infoChecker;
         CommData data;
         
         if (e.getSource() == btnOk) {
            
            try {
               Integer.parseInt(txtID.getText());
            } catch (Exception ex) {
               JOptionPane.showMessageDialog(AddNewContactDialog.this, "The ID you typed is not a valid number. Try again!");
               txtID.requestFocus();
               return;
            }
            
            data = new CommData();
            data.setCmd(CommData.CMD_ADD_CONTACT_REQ);
            data.setFrom(AddNewContactDialog.this.serverConn.getUserID()); // Who is requesting
            data.setTo(Integer.parseInt(txtID.getText())); // Contact we want to add
            
            if (serverConn.connect())
               serverConn.sendData(data);
         }
         
         AddNewContactDialog.this.setVisible(false);
         AddNewContactDialog.this.dispose();
      }
   }
}

