/*
   IM Caf - A Java Based Instant Messaging System
   Author: Bruno Freitas - 08/2004
   Contact: bootsector@ig.com.br
 
   Copyright (c) 2004 Bruno Freitas
 
   Permission is hereby granted, free of charge, to any person obtaining a copy of
   this software and associated documentation files (the "Software"), to deal in
   the Software without restriction, including without limitation the rights to
   use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
   of the Software, and to permit persons to whom the Software is furnished to do
   so, subject to the following conditions:
 
   The above copyright notice and this permission notice shall be included in all
   copies or substantial portions of the Software.
 
   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
   IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
   AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
   LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
   OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
   SOFTWARE.
 */

import java.awt.*;
import java.awt.event.*;
import javax.swing.*;
import java.net.*;

public class ClientMainWindow extends JFrame {
   private LogoPanel logoPanel;
   private ContactList contactList;
   private JPanel bottomPanel;
   private JButton menuButton;
   private JLabel statusLabel;
   private JPopupMenu menu;
   private JMenuItem mnuOptions, mnuRegUser, mnuAddContact, mnuConnect, mnuDisconnect;
   private ServerConnection serverConn;
   
   public ClientMainWindow(String version) {
      super("IM Caf v" + version);
      
      Container container = getContentPane();
      
      logoPanel = new LogoPanel(getClass().getResource("res/img/logo.png"));
      
      this.serverConn = new ServerConnection(this);
      
      contactList = new ContactList(serverConn);
      
      menu = new JPopupMenu();
      
      mnuOptions = menu.add("Options");
      mnuOptions.setIcon(new ImageIcon(getClass().getResource("res/img/options.png")));
      mnuOptions.addActionListener(
      new ActionListener() {
         public void actionPerformed(ActionEvent e) {
            ClientConfigDialog config = new ClientConfigDialog(ClientMainWindow.this);
            config.show();
         }
      }
      );
      
      menu.addSeparator();
      
      mnuRegUser = menu.add("Register a new user");
      mnuRegUser.setIcon(new ImageIcon(getClass().getResource("res/img/adduser.png")));
      mnuRegUser.addActionListener(
      new ActionListener() {
         public void actionPerformed(ActionEvent e) {
            AddNewUserDialog adduser = new AddNewUserDialog(ClientMainWindow.this, ClientMainWindow.this.serverConn);
            adduser.show();
         }
      }
      );
      
      mnuAddContact = menu.add("Add a new contact");
      mnuAddContact.setIcon(new ImageIcon(getClass().getResource("res/img/addcontact.png")));
      mnuAddContact.setEnabled(false);
      mnuAddContact.addActionListener(
      new ActionListener() {
         public void actionPerformed(ActionEvent e) {
            AddNewContactDialog adduser = new AddNewContactDialog(ClientMainWindow.this, ClientMainWindow.this.serverConn);
            adduser.show();
         }
      }
      );
      
      menu.addSeparator();
      
      mnuConnect = menu.add("Connect");
      mnuConnect.setIcon(new ImageIcon(getClass().getResource("res/img/connect.png")));
      mnuConnect.addActionListener(
      new ActionListener() {
         public void actionPerformed(ActionEvent e) {
            LoginDialog login = new LoginDialog(ClientMainWindow.this, ClientMainWindow.this.serverConn);
            login.show();
         }
      }
      );
      
      mnuDisconnect = menu.add("Disconnect");
      mnuDisconnect.setIcon(new ImageIcon(getClass().getResource("res/img/disconnect.png")));
      mnuDisconnect.setEnabled(false);
      mnuDisconnect.addActionListener(
      new ActionListener() {
         public void actionPerformed(ActionEvent e) {
            setStatusOffline();
         }
      }
      );
      
      menuButton = new JButton("Menu");
      menuButton.setIcon(new ImageIcon(getClass().getResource("res/img/menu.png")));
      menuButton.setMnemonic('M');
      menuButton.addActionListener(
      new ActionListener() {
         public void actionPerformed(ActionEvent e) {
            menu.show(menuButton, menuButton.getX(), menuButton.getY() - menu.getHeight());
            
            // This is a hack, because menu.getHeight() returns zero when called
            // for the very first time.
            menu.show(menuButton, menuButton.getX(), menuButton.getY() - menu.getHeight());
         }
      }
      );
      
      bottomPanel = new JPanel();
      bottomPanel.setLayout(new GridLayout(1, 2, 3, 0));
      
      statusLabel = new JLabel("Offline");
      statusLabel.setIcon(new ImageIcon(getClass().getResource("res/img/offline.png")));
      
      bottomPanel.add(menuButton);
      bottomPanel.add(statusLabel);
      
      container.add(logoPanel, BorderLayout.NORTH);
      container.add(new JScrollPane(contactList.getList()), BorderLayout.CENTER);
      container.add(bottomPanel, BorderLayout.SOUTH);
      
      setSize(200, 400);
      setIconImage(new ImageIcon(getClass().getResource("res/img/imcafe.png")).getImage());
      setResizable(false);
      FrameUtils.putFrameOnCorner(this);
      addWindowListener(
      new WindowAdapter() {
         public void windowClosing(WindowEvent e) {
            setStatusOffline();
         }
      }
      );
      setVisible(true);
      
      System.out.println("Client program started! Have fun! ;-)");
   }
   
   public ContactList getContactList() {
      return contactList;
   }
   
   public void enableAddContactMenu() {
      mnuAddContact.setEnabled(true);
   }
   
   public void disableAddContactMenu() {
      mnuAddContact.setEnabled(false);
   }
   
   public void enableConnectMenu() {
      mnuConnect.setEnabled(true);
   }
   
   public void disableConnectMenu() {
      mnuConnect.setEnabled(false);
   }
   
   public void enableDisconnectMenu() {
      mnuDisconnect.setEnabled(true);
   }
   
   public void disableDisconnectMenu() {
      mnuDisconnect.setEnabled(false);
   }
   
   public void setStatusOnline() {
      statusLabel.setText("Online");
      statusLabel.setIcon(new ImageIcon(getClass().getResource("res/img/online.png")));
      enableAddContactMenu();
      disableConnectMenu();
      enableDisconnectMenu();
   }
   
   public void setStatusOffline() {
      statusLabel.setText("Offline");
      statusLabel.setIcon(new ImageIcon(getClass().getResource("res/img/offline.png")));
      disableAddContactMenu();
      enableConnectMenu();
      disableDisconnectMenu();
      contactList.clearList();
      serverConn.disconnect();
   }
   
   private class LogoPanel extends JPanel {
      private ImageIcon logoImage;
      
      public LogoPanel(URL img) {
         super();
         logoImage = new ImageIcon(img);
      }
      
      public void paint(Graphics g) {
         super.paint(g);
         g.drawImage(logoImage.getImage(), 0, 0, this);
      }
      
      public Dimension getPreferredSize() {
         return new Dimension(logoImage.getIconWidth(), logoImage.getIconHeight());
      }
   }
}
