/*
   IM Caf - A Java Based Instant Messaging System
   Author: Bruno Freitas - 08/2004
   Contact: bootsector@ig.com.br
 
   Copyright (c) 2004 Bruno Freitas
 
   Permission is hereby granted, free of charge, to any person obtaining a copy of
   this software and associated documentation files (the "Software"), to deal in
   the Software without restriction, including without limitation the rights to
   use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
   of the Software, and to permit persons to whom the Software is furnished to do
   so, subject to the following conditions:
 
   The above copyright notice and this permission notice shall be included in all
   copies or substantial portions of the Software.
 
   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
   IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
   AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
   LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
   OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
   SOFTWARE.
 */

import java.net.*;
import java.io.*;
import java.util.*;
import javax.swing.*;

public class DataHandler extends Thread {
   private ServerConnection sc;
   private CommData commData;
   private ClientMainWindow mainWindow;
   
   public DataHandler(CommData commData, ClientMainWindow mainWindow, ServerConnection sc) {
      this.sc = sc;
      this.commData = commData;
      this.mainWindow = mainWindow;
   }
   
   public void run() {
      switch(commData.getCmd()) {
         case CommData.CMD_GENERIC_MESSAGE:
            cmdGenericMessage();
            break;
            
         case CommData.CMD_LOGIN_GRANTED:
            cmdLoginGranted();
            break;
            
         case CommData.CMD_USER_IS_ONLINE:
            cmdUserIsOnline();
            break;
            
         case CommData.CMD_USER_IS_OFFLINE:
            cmdUserIsOffline();
            break;
            
         case CommData.CMD_INSTANT_MESSAGE:
            cmdInstantMessage();
            break;
            
         case CommData.CMD_ADD_CONTACT_OK:
            cmdAddContactOk();
            break;
            
         case CommData.CMD_USER_STATUS_REPLY:
            cmdUserStatusReply();
            break;
            
         case CommData.CMD_REMOVE_CONTACT_OK:
            cmdRemoveContactOk();
            break;
      }
   }
   
   private void cmdGenericMessage() {
      JOptionPane.showMessageDialog(mainWindow, commData.getData());
   }
   
   private void cmdLoginGranted() {
      StringTokenizer contacts = new StringTokenizer(commData.getData(), ",");
      sc.setSessionID(commData.getSessionID());
      sc.setUserID(commData.getTo());
      
      mainWindow.setStatusOnline();
      
      while (contacts.hasMoreTokens()) {
         StringTokenizer item = new StringTokenizer(contacts.nextToken(), ":");
         int cid = Integer.parseInt(item.nextToken());
         ContactListItem clitem = new ContactListItem(cid, item.nextToken(), sc);
         
         mainWindow.getContactList().addContact(clitem);
         
         if (Integer.parseInt(item.nextToken()) == 1)
            mainWindow.getContactList().setContactStatus(cid, ContactListItem.STATUS_ONLINE, false);
      }
   }
   
   private void cmdUserIsOnline() {
      mainWindow.getContactList().setContactStatus(Integer.parseInt(commData.getData()), ContactListItem.STATUS_ONLINE, true);
   }
   
   private void cmdUserIsOffline() {
      mainWindow.getContactList().setContactStatus(Integer.parseInt(commData.getData()), ContactListItem.STATUS_OFFLINE, true);
   }
   
   private void cmdInstantMessage() {
      int retry = 2;
      
      for(int i = 1; i <= retry; i++) {
         if (mainWindow.getContactList().addMessage(commData.getFrom(), commData.getData()))
            return;
         
         try {
            Thread.sleep(10000);
         } catch (Exception e) {}
      }
   }
   
   private void cmdAddContactOk() {
      StringTokenizer tokens = new StringTokenizer(commData.getData(), ":");
      
      int cid = Integer.parseInt(tokens.nextToken());
      String nick = tokens.nextToken();
      int online = Integer.parseInt(tokens.nextToken());
      
      mainWindow.getContactList().addContact(new ContactListItem(cid, nick, sc));
      
      if (online == 1)
         mainWindow.getContactList().setContactStatus(cid, ContactListItem.STATUS_ONLINE, true);
   }
   
   private void cmdUserStatusReply() {
      StringTokenizer tokens = new StringTokenizer(commData.getData(), ":");
      
      int cid = Integer.parseInt(tokens.nextToken());
      int online = Integer.parseInt(tokens.nextToken());
      
      if (online == 1)
         mainWindow.getContactList().setContactStatus(cid, ContactListItem.STATUS_ONLINE, false);
      else
         mainWindow.getContactList().setContactStatus(cid, ContactListItem.STATUS_OFFLINE, false);
   }
   
   private void cmdRemoveContactOk() {
      mainWindow.getContactList().removeContact(commData.getTo());
   }
}
