/* 
   IM Caf - A Java Based Instant Messaging System
   Author: Bruno Freitas - 08/2004
   Contact: bootsector@ig.com.br
 
   Copyright (c) 2004 Bruno Freitas

   Permission is hereby granted, free of charge, to any person obtaining a copy of
   this software and associated documentation files (the "Software"), to deal in 
   the Software without restriction, including without limitation the rights to 
   use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies 
   of the Software, and to permit persons to whom the Software is furnished to do 
   so, subject to the following conditions:

   The above copyright notice and this permission notice shall be included in all 
   copies or substantial portions of the Software.

   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR 
   IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, 
   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE 
   AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
   LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, 
   OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE 
   SOFTWARE.
*/

import java.awt.*;
import java.awt.event.*;
import javax.swing.*;
import java.io.*;
import java.net.*;

public class LoginDialog extends JDialog {
   private JLabel lblID, lblPass;
   private JTextField txtID;
   private JPasswordField txtPass;
   private JButton btnLogin, btnClose;
   private JPanel dataPanel, btnPanel;
   private ServerConnection sc;
   
   public LoginDialog(Frame owner, ServerConnection sc){
      super(owner, "Login", true);
      
      dataPanel = new JPanel(new GridLayout(4, 1));
      
      lblID = new JLabel("User ID:");
      lblPass = new JLabel("Password:");
      
      txtID = new JTextField();
      txtPass = new JPasswordField();
      
      dataPanel.add(lblID);
      dataPanel.add(txtID);
      dataPanel.add(lblPass);
      dataPanel.add(txtPass);
      
      BtnHandler handler = new BtnHandler();
      
      btnPanel = new JPanel(new GridLayout(1, 2));
      btnLogin = new JButton("Login");
      btnLogin.setIcon(new ImageIcon(getClass().getResource("res/img/confirm.png")));
      btnLogin.setMnemonic('L');
      btnLogin.addActionListener(handler);
      btnClose = new JButton("Close");
      btnClose.setIcon(new ImageIcon(getClass().getResource("res/img/closewindow.png")));
      btnClose.setMnemonic('C');
      btnClose.addActionListener(handler);
      btnPanel.add(btnLogin);
      btnPanel.add(btnClose);
      
      getContentPane().add(dataPanel, BorderLayout.NORTH);
      getContentPane().add(btnPanel, BorderLayout.SOUTH);
      
      getRootPane().setDefaultButton(btnLogin);
      
      setSize(180, 150);
      
      setDefaultCloseOperation(JDialog.DISPOSE_ON_CLOSE);
      setLocationRelativeTo(owner);
      setResizable(false);
      
      this.sc = sc;
   }
   
   private class BtnHandler implements ActionListener {
      public void actionPerformed(ActionEvent e) {
         if (e.getSource() == btnLogin) {
            try {
               Integer.parseInt(txtID.getText());
            } catch (Exception ex) {
               JOptionPane.showMessageDialog(LoginDialog.this, "The ID you typed is not a valid number. Try again!");
               txtID.requestFocus();
               return;
            }
            
            String passwd = new String(txtPass.getPassword());
            
            if (passwd.length() == 0) {
               JOptionPane.showMessageDialog(LoginDialog.this, "You must specify a Password!");
               txtPass.requestFocus();
               return;
            }
            
            CommData data = new CommData();
            data.setCmd(CommData.CMD_LOGIN_REQUEST);
            data.setData(txtID.getText() + ":" + passwd);
            
            if (sc.connect()) {
               sc.sendData(data);
            }
         }
         
         LoginDialog.this.setVisible(false);
         LoginDialog.this.dispose();
      }
   }
}

