/* 
   IM Caf - A Java Based Instant Messaging System
   Author: Bruno Freitas - 08/2004
   Contact: bootsector@ig.com.br
 
   Copyright (c) 2004 Bruno Freitas

   Permission is hereby granted, free of charge, to any person obtaining a copy of
   this software and associated documentation files (the "Software"), to deal in 
   the Software without restriction, including without limitation the rights to 
   use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies 
   of the Software, and to permit persons to whom the Software is furnished to do 
   so, subject to the following conditions:

   The above copyright notice and this permission notice shall be included in all 
   copies or substantial portions of the Software.

   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR 
   IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, 
   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE 
   AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
   LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, 
   OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE 
   SOFTWARE.
*/

import java.awt.*;
import java.awt.event.*;
import javax.swing.*;
import java.net.*;
import java.io.*;

public class ServerConnection {
   private Socket conn;
   private OutputStream os;
   private ObjectOutputStream oos;
   private ClientMainWindow mainWindow;
   private int session_id;
   private int user_id;
   private boolean connected; // Need this because Socket.isConnected() did not
                              // work properly. :-(
   
   public ServerConnection(ClientMainWindow mainWindow) {
      this.conn = null;
      this.os = null;
      this.oos = null;
      this.connected = false;
      this.session_id = -1;
      this.user_id = -1;
      this.mainWindow = mainWindow;
   }
   
   public boolean connect() {
      FileInputStream fis = null;
      ObjectInputStream ois = null;
      ClientConfigData tmp;
      
      if (connected) return true;
      
      try {
         fis = new FileInputStream("config.dat");
         ois = new ObjectInputStream(fis);
         
         tmp = (ClientConfigData) ois.readObject();
         
         ois.close();
         fis.close();
      } catch (Exception e) {
         JOptionPane.showMessageDialog(mainWindow, "Could not read config file. You must configure the program!");
         return false;
      }
      
      try {
         conn = new Socket(tmp.getServerIP(), tmp.getServerPort());
         os = conn.getOutputStream();
         oos = new ObjectOutputStream(os);
      } catch (Exception e) {
         JOptionPane.showMessageDialog(mainWindow, "Could not connect to server!");
         return false;
      }
      
      try {
         new ServerReader(conn, mainWindow, this).start();
      } catch (Exception e) {
         throw new RuntimeException(e);
      }
      
      this.connected = true;
      return true;
   }
   
   public void setSessionID(int id) {
      session_id = id;
   }
   
   public int getSessionID() {
      return session_id;
   }
   
   public boolean isConnected() {
      if (conn == null) return false;
      return this.connected;
   }
   
   public boolean sendData(CommData data) {
      if (!isConnected()) return false;
      
      try {
         oos.writeObject(data);
         oos.flush();
      } catch (Exception e) {
         return false;
      }
      
      return true;
   }
   
   public void disconnect() {
      if (!connected) return;
      
      try {
         conn.close();
      } catch (Exception e) {
         // Nothing to do... Silent mode! :-)
      }
      
      this.connected = false;
   }
   
   public void setUserID(int id) {
      user_id = id;
   }
   
   public int getUserID() {
      return user_id;
   }
}
